@@ -2,9 +2,9 @@
 Module      : HsLua
 Copyright   : © 2007–2012 Gracjan Polak;
               © 2012–2016 Ömer Sinan Ağacan;
-              © 2017-2022 Albert Krewinkel
+              © 2017-2023 Albert Krewinkel
 License     : MIT
-Maintainer  : Albert Krewinkel <tarleb+hslua@zeitkraut.de>
+Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 Stability   : beta
 Portability : non-portable (depends on GHC)
 
@@ -28,6 +28,8 @@ module HsLua (
   , module HsLua.Class.Invokable
   , module HsLua.Class.Peekable
   , module HsLua.Class.Pushable
+    -- * Marshal to and from JSON-like structures
+  , module HsLua.Aeson
     -- * Utility functions
   , getglobal'
   , setglobal'
@@ -36,6 +38,7 @@ module HsLua (
 
 import Prelude hiding (compare, concat)
 
+import HsLua.Aeson
 import HsLua.Core
 import HsLua.Class.Exposable
 import HsLua.Class.Invokable
